"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Client = void 0;
const EmptyAdapter_1 = require("../adapters/EmptyAdapter");
const UsersManager_1 = require("../managers/UsersManager");
const BotsManager_1 = require("../managers/BotsManager");
const ServersManager_1 = require("../managers/ServersManager");
const undici_1 = require("undici");
const Endpoints_1 = require("./Endpoints");
class Client {
    constructor(options, adapter) {
        this.options = options;
        this.adapter = adapter !== null && adapter !== void 0 ? adapter : new EmptyAdapter_1.EmptyAdapter();
        this.users = new UsersManager_1.UsersManager(this.options);
        this.bots = new BotsManager_1.BotsManager(this.adapter, this.options);
        this.servers = new ServersManager_1.ServersManager(this.options);
    }
    /**
     * Start statistics autopost
     * @param interval - posting interval, in ms. default - 2 * 60 * 60 * 1000 (2 hrs)
     * */
    async botStatsAutopost(interval = 2 * 60 * 60 * 1000) {
        var _a, _b, _c;
        if (this._autopost)
            return false;
        if (this.adapter instanceof EmptyAdapter_1.EmptyAdapter) {
            throw new Error('[BotiCord] Cannot perform autopost without adapter provided');
        }
        const response = await (0, undici_1.request)(`${Endpoints_1.Endpoints.MAIN_API}/v${this.options.apiVersion}/stats`, {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
                Authorization: this.options.token
            },
            body: JSON.stringify({
                servers: (_a = await this.adapter.getServers()) !== null && _a !== void 0 ? _a : 0,
                users: (_b = await this.adapter.getUsers()) !== null && _b !== void 0 ? _b : 0,
                shards: (_c = await this.adapter.getShards()) !== null && _c !== void 0 ? _c : 0
            })
        });
        if (response.statusCode === 404) {
            throw new Error('[BotiCord] Invalid API Version provided');
        }
        if (response.statusCode === 403 || response.statusCode === 401) {
            throw new Error('[BotiCord] Invalid token provided');
        }
        this._autopost = setInterval(() => {
            this.bots.postStats(this.adapter);
        }, interval);
        return true;
    }
    /** Stop autoposting */
    shutdownAutopost() {
        if (!this._autopost)
            return false;
        clearInterval(this._autopost);
        this._autopost = undefined;
        return true;
    }
}
exports.Client = Client;
