"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BotsManager = void 0;
const undici_1 = require("undici");
const Endpoints_1 = require("../core/Endpoints");
class BotsManager {
    constructor(adapter, options) {
        this.adapter = adapter;
        this.options = options;
    }
    /**
     * Perform bots search
     * @param query - search query
     * */
    async search(query) {
        const response = await (0, undici_1.request)(`${Endpoints_1.Endpoints.MAIN_WEBSITE}/search`, {
            method: 'POST',
            headers: {
                'Content-Type': 'application/x-www-form-urlencoded'
            },
            body: JSON.stringify({
                term: query
            }),
        });
        return response.body.json();
    }
    /**
     * Get bot information using id/short code
     * @param id - bot id or short code
     * */
    async info(id) {
        const response = await (0, undici_1.request)(`${Endpoints_1.Endpoints.MAIN_API}/v${this.options.apiVersion}/bot/${id}`, {
            method: 'GET',
            headers: {
                Authorization: this.options.token
            }
        });
        return response.body.json();
    }
    /**
     * Get bot comments
     * @param id - bot id
     * */
    async comments(id) {
        const response = await (0, undici_1.request)(`${Endpoints_1.Endpoints.MAIN_API}/v${this.options.apiVersion}/bot/${id}/comments`, {
            method: 'GET',
            headers: {
                Authorization: this.options.token
            }
        });
        return response.body.json();
    }
    /**
     * Post bot statistics
     * @param statsOrAdapter - adapter or raw stats
     * */
    async postStats(statsOrAdapter) {
        const body = {
            servers: 0,
            shards: 0,
            users: 0,
        };
        if ('servers' in statsOrAdapter) {
            body.servers = statsOrAdapter.servers;
        }
        if ('shards' in statsOrAdapter) {
            body.shards = statsOrAdapter.shards;
        }
        if ('users' in statsOrAdapter) {
            body.users = statsOrAdapter.users;
        }
        if ('getServers' in statsOrAdapter) {
            body.servers = await statsOrAdapter.getServers();
        }
        if ('getShards' in statsOrAdapter) {
            body.shards = await statsOrAdapter.getShards();
        }
        if ('getUsers' in statsOrAdapter) {
            body.users = await statsOrAdapter.getUsers();
        }
        const response = await (0, undici_1.request)(`${Endpoints_1.Endpoints.MAIN_API}/v${this.options.apiVersion}/stats`, {
            method: 'POST',
            body: JSON.stringify(body),
            headers: {
                'Content-Type': 'application/json',
                Authorization: this.options.token
            },
        });
        return (response.statusCode > 199 && response.statusCode < 300) && (await response.body.json()).ok;
    }
}
exports.BotsManager = BotsManager;
