"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ServersManager = void 0;
const undici_1 = require("undici");
const Endpoints_1 = require("../core/Endpoints");
class ServersManager {
    constructor(options) {
        this.options = options;
    }
    /**
     * Perform servers search
     * @param query - search query
     * */
    async search(query) {
        const response = await (0, undici_1.request)(`${Endpoints_1.Endpoints.MAIN_WEBSITE}/search/server`, {
            method: 'POST',
            headers: {
                'Content-Type': 'application/x-www-form-urlencoded'
            },
            body: JSON.stringify({
                term: query
            }),
        });
        return response.body.json();
    }
    /**
     * Get server information using id/short code
     * @param id - server id or short code
     * */
    async info(id) {
        const response = await (0, undici_1.request)(`${Endpoints_1.Endpoints.MAIN_API}/v${this.options.apiVersion}/server/${id}`, {
            method: 'GET',
            headers: {
                Authorization: this.options.token
            }
        });
        return response.body.json();
    }
    /**
     * Get server comments
     * @param id - server id
     * */
    async comments(id) {
        const response = await (0, undici_1.request)(`${Endpoints_1.Endpoints.MAIN_API}/v${this.options.apiVersion}/server/${id}/comments`, {
            method: 'GET',
            headers: {
                Authorization: this.options.token
            }
        });
        return response.body.json();
    }
    /**
     * Post server info
     * @param info - server info
     * */
    async postInfo(info) {
        if (typeof info.status !== 'number' || typeof info.serverID !== 'string' || typeof info.up !== 'number') {
            throw new Error('[BotiCord] Invalid server update payload. ' +
                '"status" must be a number; ' +
                '"serverID" must be string; ' +
                '"up" must be a number.');
        }
        const response = await (0, undici_1.request)(`${Endpoints_1.Endpoints.MAIN_API}/v${this.options.apiVersion}/server`, {
            method: 'POST',
            body: JSON.stringify(info),
            headers: {
                'Content-Type': 'application/json',
                Authorization: this.options.token
            }
        });
        return response.body.json();
    }
}
exports.ServersManager = ServersManager;
